<?php
/**
 * Adds the necessary script to the header
 *
 * @since 0.1
 */
function nlws_ehfi_add_scripts() {
	wp_enqueue_script('jquery');
	wp_enqueue_script('jquery-ui-core');
	wp_enqueue_script('jquery-ui-tabs');
}


/**
 * Inserts header scripts
 *
 * @since 0.1
 */
function nlws_ehfi_admin_header() {
	echo '<link type="text/css" rel="stylesheet" href="' . NLWS_EHFI_URL . 'css/jquery-ui-1.8.16.custom.css" />';
	echo '<script type="text/javascript" src="' . NLWS_EHFI_URL . 'js/ehfi.js"></script>';
}


/**
 * Outputs a checked="checked" if the value is checked
 *
 * @since 0.1
 */
function nlws_ehfi_checked( $value, $optionname ) {
	if ($optionname == $value)
		echo ' checked="checked"';	
}


/**
 * Add options page
 *
 * @since 0.1
 */
function nlws_ehfi_plugin_menu() {
	// Create a new options page
	$plugin_page = add_options_page( 'Enhanced Header / Footer Injections', 'Enhanced Header / Footer Injections', 'manage_options', 'nlws-ehfi-options', 'nlws_ehfi_options');
	add_action( 'admin_head-'. $plugin_page, 'nlws_ehfi_admin_header' );
}


/**
 * Register settings
 *
 * @since 0.1
 */
function nlws_ehfi_register_settings() {
	// Register the settings
	register_setting( 'nlws_ehfi_settings', 'nlws_ehfi_settings' );
}


/**
 * Plugin activation hook
 *
 * @since 0.1
 */
function nlws_ehfi_activate() {
	// Only send if the plugin hasn't been activated before
	$isinstalled = get_option('nlws_ehfi_version');
	
	if (!$isinstalled) {
		
	}
	
	// Update version
	update_option( 'nlws_ehfi_version', NLWS_EHFI_VERSION );
	
	// Check to see if there are any default settings
	$hasglobaloptions = get_option('nlws_ehfi_settings');
	
	if (!$hasglobaloptions) {
		$defaultoptions = '';
		update_option('nlws_ehfi_settings', $defaultoptions);
	}
}


/**
 * Add our meta box
 *
 * @since 0.1
 */
function nlws_ehfi_add_meta() {
	$options = get_option( 'nlws_ehfi_settings' );
	$post_types = get_post_types();
	
	foreach ($post_types as $post_type ) :
		if ($options['enable_post_type_' . $post_type]) {
			add_meta_box('nlws_ehfi_meta_section',
				__( 'Enhanced Header / Footer Injections', 'nlws_ehfi_domain' ), 
				'nlws_ehfi_output_meta',
				$post_type
			);
		}
	endforeach;
}


/**
 * Save the meta information
 *
 * @since 0.1
 */
function nlws_ehfi_save_post( $post_id ) {
	/**
	 * Verify if this is an auto save routine. 
	 * If it is our form has not been submitted, so we dont want to do anything
	 */
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
		return;


	/**
	 * Verify this came from the our screen and with proper authorization,
	 * because save_post can be triggered at other times
	 *
	 * This is strange... I think this might not work on a local dev environment
	 */
	/*if ( !wp_verify_nonce( $_POST['nlws_ehfi_noncename'], plugin_basename( __FILE__ ) ) )
		return;*/


	/**
	 * Check permissions
	 */
	if ( 'page' == $_POST['post_type'] ) {
		if ( !current_user_can( 'edit_page', $post_id ) )
			return;
	}
	else {
		if ( !current_user_can( 'edit_post', $post_id ) )
			return;
	}

	
	/**
	 * OK, we're authenticated: we need to find and save the data
	 */
	$mydata = $_POST['nlws_ehfi_meta'];
	//$mydata = $_POST;
	update_post_meta($post_id, '_nlws_efhi', $mydata);
}


/**
 * Outputs the header code
 *
 * @since 0.1
 */
function nlws_ehfi_head(){
	$options = get_option( 'nlws_ehfi_settings' );
	
	if ( is_home() )
		echo $options['main_blog_page_header'];
		
	elseif ( is_404() )
		echo $options['404_page_header'];
		
	else {
		global $post;
		$post_type = $post->post_type;
	
		if ($options['enable_post_type_' . $post->post_type] == 1) {
			if (is_archive()) {
				echo $options[$post_type . '_archives_header'];
			}
			else {
				$meta = get_post_meta($post->ID,'_nlws_efhi',TRUE);
				
				switch ($meta['header_mode']) {
					case 'global' :
						echo $options['global_header'];
						break;
					case 'post_global' :
						echo $options[$post_type . '_single_header'];
					case 'perpage' :
						echo $meta['header_text'];
						break;
				}
			}
		}	
	}
}


/**
 * Outputs the footer code
 *
 * @since 0.1
 */
function nlws_ehfi_footer(){
	$options = get_option( 'nlws_ehfi_settings' );
	
	if ( is_home() )
		echo $options['main_blog_page_footer'];
		
	elseif ( is_404() )
		echo $options['404_page_footer'];
		
	else {
		global $post;
		$post_type = $post->post_type;
		
		if (($options['enable_post_type_' . $post_type] == 1)) {
			if (is_archive()) {
				echo $options[$post_type . '_archives_footer'];
			}
			else {
				$meta = get_post_meta($post->ID,'_nlws_efhi',TRUE);
				
				switch ($meta['footer_mode']) {
					case 'global' :
						echo $options['global_footer'];
						break;
					case 'post_global' :
						echo $options[$post_type . '_single_footer'];
						break;
					case 'perpage' :
						echo $meta['footer_text'];
						break;
				}
			}
		}
	}
}


/**
 * Check to see if there are any enabled post types
 *
 * @since 0.2
 * @return bool
 */
function nlws_ehfi_are_enabled_post_types() {
	$options = get_option( 'nlws_ehfi_settings' );
	$post_types = get_post_types();
	
	$post_type_count;
	
	foreach( $post_types as $post_type ) {
		if ( $options['enable_post_type_' . $post_type] == 1 )
			if ( ( nlws_ehfi_acceptable_post_type( $post_type ) ) && ( $post_type != 'page' ) )
				$post_type_count++;
	}
	
	if ($post_type_count > 0)
		return true;
}


/**
 * Return true if the post type is deemed acceptable
 *
 * @since 0.2
 * @return bool
 */
function nlws_ehfi_acceptable_post_type( $post_type ) {
	global $nlws_ehfi_unacceptable_post_types;
	
	foreach ( $nlws_ehfi_unacceptable_post_types as $bad ) {
		if ( $bad == $post_type )
			return false;
	}
	
	return true;
}